@@ -1,5 +1,5 @@
 /* gsasl-saml20-request.c --- Generate SAML Request, for smtp-server-saml20.
- * Copyright (C) 2012-2022 Simon Josefsson
+ * Copyright (C) 2012-2024 Simon Josefsson
  *
  * This file is part of GNU SASL.
  *
@@ -93,7 +93,7 @@ write_file (const char *file, const char *data)
 }
 
 static void
-write_authreq (LassoLogin * login, const char *state_path, const char *id)
+write_authreq (LassoLogin *login, const char *state_path, const char *id)
 {
   LassoNode *authreq;
   char *authreq_xml;
@@ -129,8 +129,7 @@ write_authreq (LassoLogin * login, const char *state_path, const char *id)
 }
 
 static void
-write_redirect_url (LassoLogin * login, const char *state_path,
-		    const char *id)
+write_redirect_url (LassoLogin *login, const char *state_path, const char *id)
 {
   char *filename;
   int rc;
