@@ -1,5 +1,5 @@
 /* server.c --- SASL CRAM-MD5 server side functions.
- * Copyright (C) 2002-2022 Simon Josefsson
+ * Copyright (C) 2002-2024 Simon Josefsson
  *
  * This file is part of GNU SASL Library.
  *
@@ -20,9 +20,7 @@
  *
  */
 
-#ifdef HAVE_CONFIG_H
-# include "config.h"
-#endif
+#include <config.h>
 
 /* Get specification. */
 #include "cram-md5.h"
@@ -42,7 +40,7 @@
 #define MD5LEN 16
 
 int
-_gsasl_cram_md5_server_start (Gsasl_session * sctx _GL_UNUSED,
+_gsasl_cram_md5_server_start (Gsasl_session *sctx _GL_UNUSED,
 			      void **mech_data)
 {
   char *challenge;
@@ -65,7 +63,7 @@ _gsasl_cram_md5_server_start (Gsasl_session * sctx _GL_UNUSED,
 }
 
 int
-_gsasl_cram_md5_server_step (Gsasl_session * sctx,
+_gsasl_cram_md5_server_step (Gsasl_session *sctx,
 			     void *mech_data,
 			     const char *input, size_t input_len,
 			     char **output, size_t *output_len)
@@ -129,7 +127,7 @@ _gsasl_cram_md5_server_step (Gsasl_session * sctx,
 }
 
 void
-_gsasl_cram_md5_server_finish (Gsasl_session * sctx _GL_UNUSED,
+_gsasl_cram_md5_server_finish (Gsasl_session *sctx _GL_UNUSED,
 			       void *mech_data)
 {
   char *challenge = mech_data;
