@@ -1,5 +1,5 @@
 /* getsubopt.c --- Parse comma separate list into words, DIGEST-MD5 style.
- * Copyright (C) 2002-2022 Simon Josefsson
+ * Copyright (C) 2002-2024 Simon Josefsson
  * Copyright (C) 1996, 1997, 1999 Free Software Foundation, Inc.
  * From the GNU C Library, under GNU LGPL version 2.1.
  * Contributed by Ulrich Drepper <drepper@cygnus.com>, 1996.
@@ -24,9 +24,7 @@
  *
  */
 
-#ifdef HAVE_CONFIG_H
-# include "config.h"
-#endif
+#include <config.h>
 
 /* Get prototypes. */
 #include "parser.h"
@@ -70,7 +68,7 @@ digest_md5_getsubopt (char **optionp,
   /* Try to match the characters between *OPTIONP and VSTART against
      one of the TOKENS.  */
   for (cnt = 0; tokens[cnt] != NULL; ++cnt)
-    if (memcmp (*optionp, tokens[cnt], vstart - *optionp) == 0
+    if (strncmp (*optionp, tokens[cnt], vstart - *optionp) == 0
 	&& tokens[cnt][vstart - *optionp] == '\0')
       {
 	/* We found the current option in TOKENS.  */
