@@ -1,5 +1,5 @@
 /* parser.c --- DIGEST-MD5 parser.
- * Copyright (C) 2002-2022 Simon Josefsson
+ * Copyright (C) 2002-2024 Simon Josefsson
  *
  * This file is part of GNU SASL Library.
  *
@@ -20,9 +20,7 @@
  *
  */
 
-#ifdef HAVE_CONFIG_H
-# include "config.h"
-#endif
+#include <config.h>
 
 /* Get prototypes. */
 #include "parser.h"
@@ -109,7 +107,7 @@ static const char *const cipher_opts[] = {
 };
 
 static int
-parse_challenge (char *challenge, digest_md5_challenge * out)
+parse_challenge (char *challenge, digest_md5_challenge *out)
 {
   int done_algorithm = 0;
   int disable_qop_auth_conf = 0;
@@ -347,7 +345,7 @@ static const char *const digest_response_opts[] = {
 };
 
 static int
-parse_response (char *response, digest_md5_response * out)
+parse_response (char *response, digest_md5_response *out)
 {
   char *value;
 
@@ -531,7 +529,7 @@ static const char *const digest_responseauth_opts[] = {
 };
 
 static int
-parse_finish (char *finish, digest_md5_finish * out)
+parse_finish (char *finish, digest_md5_finish *out)
 {
   char *value;
 
@@ -567,7 +565,7 @@ parse_finish (char *finish, digest_md5_finish * out)
 
 int
 digest_md5_parse_challenge (const char *challenge, size_t len,
-			    digest_md5_challenge * out)
+			    digest_md5_challenge *out)
 {
   char *subopts = len ? strndup (challenge, len) : strdup (challenge);
   int rc;
@@ -584,7 +582,7 @@ digest_md5_parse_challenge (const char *challenge, size_t len,
 
 int
 digest_md5_parse_response (const char *response, size_t len,
-			   digest_md5_response * out)
+			   digest_md5_response *out)
 {
   char *subopts = len ? strndup (response, len) : strdup (response);
   int rc;
@@ -601,7 +599,7 @@ digest_md5_parse_response (const char *response, size_t len,
 
 int
 digest_md5_parse_finish (const char *finish, size_t len,
-			 digest_md5_finish * out)
+			 digest_md5_finish *out)
 {
   char *subopts = len ? strndup (finish, len) : strdup (finish);
   int rc;
