@@ -1,5 +1,5 @@
 /* printer.h --- Convert DIGEST-MD5 token structures into strings.
- * Copyright (C) 2004-2022 Simon Josefsson
+ * Copyright (C) 2004-2024 Simon Josefsson
  *
  * This file is part of GNU SASL Library.
  *
@@ -20,9 +20,7 @@
  *
  */
 
-#ifdef HAVE_CONFIG_H
-# include "config.h"
-#endif
+#include <config.h>
 
 /* Get prototypes. */
 #include "printer.h"
@@ -71,7 +69,7 @@ comma_append (char **dst, const char *key, const char *value, int quotes)
 }
 
 char *
-digest_md5_print_challenge (digest_md5_challenge * c)
+digest_md5_print_challenge (digest_md5_challenge *c)
 {
   char *out = NULL;
   size_t i;
@@ -240,7 +238,7 @@ digest_md5_print_challenge (digest_md5_challenge * c)
 }
 
 char *
-digest_md5_print_response (digest_md5_response * r)
+digest_md5_print_response (digest_md5_response *r)
 {
   char *out = NULL;
   const char *qop = NULL;
@@ -384,7 +382,7 @@ digest_md5_print_response (digest_md5_response * r)
 }
 
 char *
-digest_md5_print_finish (digest_md5_finish * finish)
+digest_md5_print_finish (digest_md5_finish *finish)
 {
   char *out;
 
