@@ -1,5 +1,5 @@
 /* server.c --- DIGEST-MD5 mechanism from RFC 2831, server side.
- * Copyright (C) 2002-2022 Simon Josefsson
+ * Copyright (C) 2002-2024 Simon Josefsson
  *
  * This file is part of GNU SASL Library.
  *
@@ -20,9 +20,7 @@
  *
  */
 
-#ifdef HAVE_CONFIG_H
-# include "config.h"
-#endif
+#include <config.h>
 
 /* Get specification. */
 #include "digest-md5.h"
@@ -66,7 +64,7 @@ struct _Gsasl_digest_md5_server_state
 typedef struct _Gsasl_digest_md5_server_state _Gsasl_digest_md5_server_state;
 
 int
-_gsasl_digest_md5_server_start (Gsasl_session * sctx _GL_UNUSED,
+_gsasl_digest_md5_server_start (Gsasl_session *sctx _GL_UNUSED,
 				void **mech_data)
 {
   _Gsasl_digest_md5_server_state *state;
@@ -145,7 +143,7 @@ _gsasl_digest_md5_set_hashed_secret (char *secret, const char *hex_secret)
 }
 
 int
-_gsasl_digest_md5_server_step (Gsasl_session * sctx,
+_gsasl_digest_md5_server_step (Gsasl_session *sctx,
 			       void *mech_data,
 			       const char *input,
 			       size_t input_len,
@@ -348,7 +346,7 @@ _gsasl_digest_md5_server_step (Gsasl_session * sctx,
 }
 
 void
-_gsasl_digest_md5_server_finish (Gsasl_session * sctx _GL_UNUSED,
+_gsasl_digest_md5_server_finish (Gsasl_session *sctx _GL_UNUSED,
 				 void *mech_data)
 {
   _Gsasl_digest_md5_server_state *state = mech_data;
@@ -364,7 +362,7 @@ _gsasl_digest_md5_server_finish (Gsasl_session * sctx _GL_UNUSED,
 }
 
 int
-_gsasl_digest_md5_server_encode (Gsasl_session * sctx _GL_UNUSED,
+_gsasl_digest_md5_server_encode (Gsasl_session *sctx _GL_UNUSED,
 				 void *mech_data,
 				 const char *input,
 				 size_t input_len,
@@ -388,7 +386,7 @@ _gsasl_digest_md5_server_encode (Gsasl_session * sctx _GL_UNUSED,
 }
 
 int
-_gsasl_digest_md5_server_decode (Gsasl_session * sctx _GL_UNUSED,
+_gsasl_digest_md5_server_decode (Gsasl_session *sctx _GL_UNUSED,
 				 void *mech_data,
 				 const char *input,
 				 size_t input_len,
