@@ -1,5 +1,5 @@
 /* server.c --- EXTERNAL mechanism as defined in RFC 2222, server side.
- * Copyright (C) 2002-2022 Simon Josefsson
+ * Copyright (C) 2002-2024 Simon Josefsson
  *
  * This file is part of GNU SASL Library.
  *
@@ -20,9 +20,7 @@
  *
  */
 
-#ifdef HAVE_CONFIG_H
-# include "config.h"
-#endif
+#include <config.h>
 
 /* Get specification. */
 #include "external.h"
@@ -31,7 +29,7 @@
 #include <string.h>
 
 int
-_gsasl_external_server_step (Gsasl_session * sctx,
+_gsasl_external_server_step (Gsasl_session *sctx,
 			     void *mech_data _GL_UNUSED,
 			     const char *input, size_t input_len,
 			     char **output, size_t *output_len)
