@@ -1,5 +1,5 @@
 /* gs2helper.c --- GS2 helper functions common to client and server.
- * Copyright (C) 2010-2022 Simon Josefsson
+ * Copyright (C) 2010-2024 Simon Josefsson
  *
  * This file is part of GNU SASL Library.
  *
@@ -20,9 +20,7 @@
  *
  */
 
-#ifdef HAVE_CONFIG_H
-# include "config.h"
-#endif
+#include <config.h>
 
 /* Get strcmp. */
 #include <string.h>
@@ -37,7 +35,7 @@
    bit silly given that we only support Kerberos V5 today, but will be
    useful when that changes.  */
 int
-gs2_get_oid (Gsasl_session * sctx, gss_OID * mech_oid)
+gs2_get_oid (Gsasl_session *sctx, gss_OID *mech_oid)
 {
   gss_buffer_desc sasl_mech_name;
   OM_uint32 maj_stat, min_stat;
