@@ -1,5 +1,5 @@
 /* server.c --- SASL mechanism GS2, server side.
- * Copyright (C) 2002-2021 Simon Josefsson
+ * Copyright (C) 2002-2024 Simon Josefsson
  *
  * This file is part of GNU SASL Library.
  *
@@ -20,9 +20,7 @@
  *
  */
 
-#ifdef HAVE_CONFIG_H
-# include "config.h"
-#endif
+#include <config.h>
 
 /* Get specification. */
 #include "gs2.h"
@@ -55,7 +53,7 @@ typedef struct _Gsasl_gs2_server_state _Gsasl_gs2_server_state;
 /* Populate state->cred with credential to use for connection.  Return
    GSASL_OK on success or an error code.  */
 static int
-gs2_get_cred (Gsasl_session * sctx, _Gsasl_gs2_server_state * state)
+gs2_get_cred (Gsasl_session *sctx, _Gsasl_gs2_server_state *state)
 {
   OM_uint32 maj_stat, min_stat;
   gss_buffer_desc bufdesc;
@@ -118,7 +116,7 @@ gs2_get_cred (Gsasl_session * sctx, _Gsasl_gs2_server_state * state)
 /* Initialize GS2 state into MECH_DATA.  Return GSASL_OK if GS2 is
    ready and initialization succeeded, or an error code. */
 int
-_gsasl_gs2_server_start (Gsasl_session * sctx, void **mech_data)
+_gsasl_gs2_server_start (Gsasl_session *sctx, void **mech_data)
 {
   _Gsasl_gs2_server_state *state;
   int res;
@@ -161,7 +159,7 @@ _gsasl_gs2_server_start (Gsasl_session * sctx, void **mech_data)
    expected to be put in newly allocated OUTPUT/OUTPUT_LEN.  Return
    GSASL_NEEDS_MORE or GSASL_OK on success, or an error code.  */
 int
-_gsasl_gs2_server_step (Gsasl_session * sctx,
+_gsasl_gs2_server_step (Gsasl_session *sctx,
 			void *mech_data,
 			const char *input, size_t input_len,
 			char **output, size_t *output_len)
@@ -298,7 +296,7 @@ _gsasl_gs2_server_step (Gsasl_session * sctx,
 /* Cleanup GS2 state context, i.e., release memory associated with
    buffers in MECH_DATA state. */
 void
-_gsasl_gs2_server_finish (Gsasl_session * sctx, void *mech_data)
+_gsasl_gs2_server_finish (Gsasl_session *sctx, void *mech_data)
 {
   _Gsasl_gs2_server_state *state = mech_data;
   OM_uint32 min_stat;
