@@ -1,5 +1,5 @@
 /* server.c --- SASL mechanism GSSAPI as defined in RFC 4752, server side.
- * Copyright (C) 2002-2022 Simon Josefsson
+ * Copyright (C) 2002-2024 Simon Josefsson
  *
  * This file is part of GNU SASL Library.
  *
@@ -20,9 +20,7 @@
  *
  */
 
-#ifdef HAVE_CONFIG_H
-# include "config.h"
-#endif
+#include <config.h>
 
 /* Get malloc, free. */
 #include <stdlib.h>
@@ -46,7 +44,7 @@ struct _Gsasl_gssapi_server_state
 typedef struct _Gsasl_gssapi_server_state _Gsasl_gssapi_server_state;
 
 int
-_gsasl_gssapi_server_start (Gsasl_session * sctx, void **mech_data)
+_gsasl_gssapi_server_start (Gsasl_session *sctx, void **mech_data)
 {
   _Gsasl_gssapi_server_state *state;
 
@@ -64,7 +62,7 @@ _gsasl_gssapi_server_start (Gsasl_session * sctx, void **mech_data)
 }
 
 int
-_gsasl_gssapi_server_step (Gsasl_session * sctx,
+_gsasl_gssapi_server_step (Gsasl_session *sctx,
 			   void *mech_data,
 			   const char *input, size_t input_len,
 			   char **output, size_t *output_len)
@@ -265,7 +263,7 @@ _gsasl_gssapi_server_step (Gsasl_session * sctx,
 }
 
 void
-_gsasl_gssapi_server_finish (Gsasl_session * sctx, void *mech_data)
+_gsasl_gssapi_server_finish (Gsasl_session *sctx, void *mech_data)
 {
   _Gsasl_gssapi_server_state *state = mech_data;
   OM_uint32 min_stat;
