@@ -1,5 +1,5 @@
 /* ntlm.c --- Implementation of non-standard SASL mechanism NTLM, client side.
- * Copyright (C) 2002-2022 Simon Josefsson
+ * Copyright (C) 2002-2024 Simon Josefsson
  *
  * This file is part of GNU SASL Library.
  *
@@ -20,9 +20,7 @@
  *
  */
 
-#ifdef HAVE_CONFIG_H
-# include "config.h"
-#endif
+#include <config.h>
 
 /* Get malloc, free. */
 #include <stdlib.h>
@@ -42,7 +40,7 @@ struct _Gsasl_ntlm_state
 typedef struct _Gsasl_ntlm_state _Gsasl_ntlm_state;
 
 int
-_gsasl_ntlm_client_start (Gsasl_session * sctx _GL_UNUSED, void **mech_data)
+_gsasl_ntlm_client_start (Gsasl_session *sctx _GL_UNUSED, void **mech_data)
 {
   _Gsasl_ntlm_state *state;
 
@@ -58,7 +56,7 @@ _gsasl_ntlm_client_start (Gsasl_session * sctx _GL_UNUSED, void **mech_data)
 }
 
 int
-_gsasl_ntlm_client_step (Gsasl_session * sctx,
+_gsasl_ntlm_client_step (Gsasl_session *sctx,
 			 void *mech_data,
 			 const char *input, size_t input_len,
 			 char **output, size_t *output_len)
@@ -164,7 +162,7 @@ _gsasl_ntlm_client_step (Gsasl_session * sctx,
 }
 
 void
-_gsasl_ntlm_client_finish (Gsasl_session * sctx _GL_UNUSED, void *mech_data)
+_gsasl_ntlm_client_finish (Gsasl_session *sctx _GL_UNUSED, void *mech_data)
 {
   _Gsasl_ntlm_state *state = mech_data;
 
