@@ -1,5 +1,5 @@
 /* client.c --- OPENID20 mechanism, client side.
- * Copyright (C) 2011-2022 Simon Josefsson
+ * Copyright (C) 2011-2024 Simon Josefsson
  *
  * This file is part of GNU SASL Library.
  *
@@ -20,9 +20,7 @@
  *
  */
 
-#ifdef HAVE_CONFIG_H
-# include "config.h"
-#endif
+#include <config.h>
 
 /* Get specification. */
 #include "openid20.h"
@@ -45,7 +43,7 @@ struct openid20_client_state
 };
 
 int
-_gsasl_openid20_client_start (Gsasl_session * sctx _GL_UNUSED,
+_gsasl_openid20_client_start (Gsasl_session *sctx _GL_UNUSED,
 			      void **mech_data)
 {
   struct openid20_client_state *state;
@@ -60,7 +58,7 @@ _gsasl_openid20_client_start (Gsasl_session * sctx _GL_UNUSED,
 }
 
 int
-_gsasl_openid20_client_step (Gsasl_session * sctx,
+_gsasl_openid20_client_step (Gsasl_session *sctx,
 			     void *mech_data,
 			     const char *input, size_t input_len,
 			     char **output, size_t *output_len)
@@ -166,7 +164,7 @@ _gsasl_openid20_client_step (Gsasl_session * sctx,
 }
 
 void
-_gsasl_openid20_client_finish (Gsasl_session * sctx _GL_UNUSED,
+_gsasl_openid20_client_finish (Gsasl_session *sctx _GL_UNUSED,
 			       void *mech_data)
 {
   struct openid20_client_state *state = mech_data;
