@@ -1,5 +1,5 @@
 /* server.c --- SASL mechanism PLAIN as defined in RFC 2595, server side.
- * Copyright (C) 2002-2021 Simon Josefsson
+ * Copyright (C) 2002-2024 Simon Josefsson
  *
  * This file is part of GNU SASL Library.
  *
@@ -20,9 +20,7 @@
  *
  */
 
-#ifdef HAVE_CONFIG_H
-# include "config.h"
-#endif
+#include <config.h>
 
 /* Get specification. */
 #include "plain.h"
@@ -34,7 +32,7 @@
 #include <stdlib.h>
 
 int
-_gsasl_plain_server_step (Gsasl_session * sctx,
+_gsasl_plain_server_step (Gsasl_session *sctx,
 			  void *mech_data _GL_UNUSED,
 			  const char *input, size_t input_len,
 			  char **output, size_t *output_len)
