@@ -1,5 +1,5 @@
 /* parser.c --- SCRAM parser.
- * Copyright (C) 2009-2022 Simon Josefsson
+ * Copyright (C) 2009-2024 Simon Josefsson
  *
  * This file is part of GNU SASL Library.
  *
@@ -20,9 +20,7 @@
  *
  */
 
-#ifdef HAVE_CONFIG_H
-# include "config.h"
-#endif
+#include <config.h>
 
 /* Get prototypes. */
 #include "parser.h"
@@ -192,8 +190,6 @@ scram_parse_client_first (const char *str, size_t len,
     p = memchr (str, ',', len);
     if (!p)
       p = str + len;
-    if (!p)
-      return -1;
 
     l = p - str;
     if (len < l)
