@@ -1,5 +1,5 @@
 /* printer.h --- Convert SCRAM token structures into strings.
- * Copyright (C) 2009-2022 Simon Josefsson
+ * Copyright (C) 2009-2024 Simon Josefsson
  *
  * This file is part of GNU SASL Library.
  *
@@ -20,9 +20,7 @@
  *
  */
 
-#ifdef HAVE_CONFIG_H
-# include "config.h"
-#endif
+#include <config.h>
 
 /* Get prototypes. */
 #include "printer.h"
@@ -97,7 +95,10 @@ scram_print_client_first (struct scram_client_first *cf, char **out)
     {
       authzid = scram_escape (cf->authzid);
       if (!authzid)
-	return -2;
+	{
+	  free (username);
+	  return -2;
+	}
     }
 
   n = asprintf (out, "%c%s%s,%s%s,n=%s,r=%s",
