@@ -1,5 +1,5 @@
 /* client.c --- SASL mechanism SECURID from RFC 2808, client side.
- * Copyright (C) 2002-2022 Simon Josefsson
+ * Copyright (C) 2002-2024 Simon Josefsson
  *
  * This file is part of GNU SASL Library.
  *
@@ -20,9 +20,7 @@
  *
  */
 
-#ifdef HAVE_CONFIG_H
-# include "config.h"
-#endif
+#include <config.h>
 
 /* Get specification. */
 #include "securid.h"
@@ -37,8 +35,7 @@
 #define PIN "pin"
 
 int
-_gsasl_securid_client_start (Gsasl_session * sctx _GL_UNUSED,
-			     void **mech_data)
+_gsasl_securid_client_start (Gsasl_session *sctx _GL_UNUSED, void **mech_data)
 {
   int *step;
 
@@ -54,7 +51,7 @@ _gsasl_securid_client_start (Gsasl_session * sctx _GL_UNUSED,
 }
 
 int
-_gsasl_securid_client_step (Gsasl_session * sctx,
+_gsasl_securid_client_step (Gsasl_session *sctx,
 			    void *mech_data,
 			    const char *input,
 			    size_t input_len,
@@ -165,8 +162,7 @@ _gsasl_securid_client_step (Gsasl_session * sctx,
 }
 
 void
-_gsasl_securid_client_finish (Gsasl_session * sctx _GL_UNUSED,
-			      void *mech_data)
+_gsasl_securid_client_finish (Gsasl_session *sctx _GL_UNUSED, void *mech_data)
 {
   int *step = mech_data;
 
