@@ -1,5 +1,5 @@
 /* server.c --- SASL mechanism SECURID from RFC 2808, server side.
- * Copyright (C) 2002-2021 Simon Josefsson
+ * Copyright (C) 2002-2024 Simon Josefsson
  *
  * This file is part of GNU SASL Library.
  *
@@ -20,9 +20,7 @@
  *
  */
 
-#ifdef HAVE_CONFIG_H
-# include "config.h"
-#endif
+#include <config.h>
 
 /* Get specification. */
 #include "securid.h"
@@ -37,7 +35,7 @@
 #define PIN "pin"
 
 int
-_gsasl_securid_server_step (Gsasl_session * sctx,
+_gsasl_securid_server_step (Gsasl_session *sctx,
 			    void *mech_data _GL_UNUSED,
 			    const char *input, size_t input_len,
 			    char **output, size_t *output_len)
