@@ -1,5 +1,5 @@
 /* internal.h --- Internal header with hidden library handle structures.
- * Copyright (C) 2002-2022 Simon Josefsson
+ * Copyright (C) 2002-2024 Simon Josefsson
  *
  * This file is part of GNU SASL Library.
  *
@@ -23,10 +23,6 @@
 #ifndef INTERNAL_H
 # define INTERNAL_H
 
-# ifdef HAVE_CONFIG_H
-#  include "config.h"
-# endif
-
 /* Get specifications. */
 # include "gsasl.h"
 
