@@ -1,5 +1,5 @@
 /* mechtools.c --- Helper functions available for use by any mechanism.
- * Copyright (C) 2010-2022 Simon Josefsson
+ * Copyright (C) 2010-2024 Simon Josefsson
  *
  * This file is part of GNU SASL Library.
  *
@@ -20,9 +20,7 @@
  *
  */
 
-#ifdef HAVE_CONFIG_H
-# include "config.h"
-#endif
+#include <config.h>
 
 /* Get specification. */
 #include "mechtools.h"
@@ -114,9 +112,6 @@ _gsasl_parse_gs2_header (const char *data, size_t len,
     {
       int res;
 
-      if (authzid_endptr == NULL)
-	return GSASL_MECHANISM_PARSE_ERROR;
-
       res = unescape_authzid (data + 4, authzid_endptr - (data + 4), authzid);
       if (res != GSASL_OK)
 	return res;
@@ -211,7 +206,7 @@ _gsasl_gs2_generate_header (bool nonstd, char cbflag,
 
   free (gs2cbflag);
 
-  if (len <= 0 || gs2h == NULL)
+  if (len <= 0 || *gs2h == NULL)
     return GSASL_MALLOC_ERROR;
 
   *gs2hlen = len;
