@@ -1,5 +1,5 @@
 /* suggest.c --- Suggest client mechanism to use, from a set of mechanisms.
- * Copyright (C) 2002-2021 Simon Josefsson
+ * Copyright (C) 2002-2024 Simon Josefsson
  *
  * This file is part of GNU SASL Library.
  *
@@ -20,6 +20,7 @@
  *
  */
 
+#include <config.h>
 #include "internal.h"
 
 /*
@@ -32,11 +33,12 @@ const char *_GSASL_VALID_MECHANISM_CHARACTERS =
   "ABCDEFGHIJKLMNOPQRSTUVWXYZ0123456789-_";
 
 /**
- * gsasl_is_mechanism_name_valid:
+ * gsasl_mechanism_name_p:
  * @mech: input variable with mechanism name string.
  *
  * Check if the mechanism name string @mech follows syntactical rules.
- * It does not check that the name is registered with IANA.
+ * It does not check that the name is registered with IANA.  It does not
+ * check that the mechanism name is actually implemented and supported.
  *
  * SASL mechanisms are named by strings, from 1 to 20 characters in
  * length, consisting of upper-case letters, digits, hyphens, and/or
@@ -48,7 +50,7 @@ const char *_GSASL_VALID_MECHANISM_CHARACTERS =
  * Since: 2.0.0
  **/
 int
-gsasl_is_mechanism_name_valid (const char *mech)
+gsasl_mechanism_name_p (const char *mech)
 {
   size_t l;
 
@@ -83,7 +85,7 @@ gsasl_is_mechanism_name_valid (const char *mech)
  *   NULL if no supported mechanism is found.
  **/
 const char *
-gsasl_client_suggest_mechanism (Gsasl * ctx, const char *mechlist)
+gsasl_client_suggest_mechanism (Gsasl *ctx, const char *mechlist)
 {
   size_t mechlist_len, target_mech, i;
 
@@ -106,7 +108,9 @@ gsasl_client_suggest_mechanism (Gsasl * ctx, const char *mechlist)
 	  for (j = (target_mech < ctx->n_client_mechs ? target_mech + 1 : 0);
 	       j < ctx->n_client_mechs; ++j)
 	    {
-	      if (strncmp (ctx->client_mechs[j].name, mechlist + i, len) == 0)
+	      if ((strlen (ctx->client_mechs[j].name) == len)
+		  && (strncmp (ctx->client_mechs[j].name, mechlist + i,
+			       len) == 0))
 		{
 		  Gsasl_session *sctx;
 
