@@ -1,5 +1,5 @@
 /* smtp.c --- Implement SMTP profile of SASL login.
- * Copyright (C) 2002-2022 Simon Josefsson
+ * Copyright (C) 2002-2024 Simon Josefsson
  *
  * This file is part of GNU SASL.
  *
@@ -18,6 +18,8 @@
  *
  */
 
+#include <config.h>
+#include "internal.h"
 #include "smtp.h"
 
 int
