@@ -1,5 +1,5 @@
 /* crypto.c --- Test the crypto related SASL functions.
- * Copyright (C) 2009-2022 Simon Josefsson
+ * Copyright (C) 2009-2024 Simon Josefsson
  *
  * This file is part of GNU SASL.
  *
@@ -18,9 +18,7 @@
  *
  */
 
-#ifdef HAVE_CONFIG_H
-# include "config.h"
-#endif
+#include <config.h>
 
 #include <stdio.h>
 #include <stdlib.h>
