@@ -1,5 +1,5 @@
 /* digest-md5.c --- Test the DIGEST-MD5 mechanism.
- * Copyright (C) 2002-2022 Simon Josefsson
+ * Copyright (C) 2002-2024 Simon Josefsson
  *
  * This file is part of GNU SASL.
  *
@@ -18,9 +18,7 @@
  *
  */
 
-#ifdef HAVE_CONFIG_H
-# include "config.h"
-#endif
+#include <config.h>
 
 #include <stdio.h>
 #include <stdarg.h>
@@ -41,12 +39,14 @@
 size_t i;
 
 static int
-callback (Gsasl * ctx, Gsasl_session * sctx, Gsasl_property prop)
+callback (Gsasl *ctx, Gsasl_session *sctx, Gsasl_property prop)
 {
   static int flip = 0;
   static int flip2 = 0;
   int rc = GSASL_NO_CALLBACK;
 
+  (void) ctx;
+
   /* Get user info from user. */
 
   switch (prop)
