@@ -1,5 +1,5 @@
 /* external.c --- Test the EXTERNAL mechanism.
- * Copyright (C) 2002-2022 Simon Josefsson
+ * Copyright (C) 2002-2024 Simon Josefsson
  *
  * This file is part of GNU SASL.
  *
@@ -18,9 +18,7 @@
  *
  */
 
-#ifdef HAVE_CONFIG_H
-# include "config.h"
-#endif
+#include <config.h>
 
 #include <stdio.h>
 #include <stdarg.h>
@@ -51,11 +49,13 @@ static const struct
 int i;
 
 static int
-callback (Gsasl * ctx, Gsasl_session * sctx, Gsasl_property prop)
+callback (Gsasl *ctx, Gsasl_session *sctx, Gsasl_property prop)
 {
   unsigned j = 0;
   int rc = GSASL_NO_CALLBACK;
 
+  (void) ctx;
+
   j = i % (sizeof (tv) / sizeof (tv[0]));
 
   /* Get user info from user. */
