@@ -1,5 +1,5 @@
 /* gs2-krb5.c --- Test the GS2-KRB5 mechanism.
- * Copyright (C) 2002-2022 Simon Josefsson
+ * Copyright (C) 2002-2024 Simon Josefsson
  *
  * This file is part of GNU SASL.
  *
@@ -18,9 +18,7 @@
  *
  */
 
-#ifdef HAVE_CONFIG_H
-# include "config.h"
-#endif
+#include <config.h>
 
 #include <stdio.h>
 #include <stdarg.h>
@@ -41,10 +39,12 @@ static const char *AUTHZID[] = {
 size_t i;
 
 static int
-callback (Gsasl * ctx, Gsasl_session * sctx, Gsasl_property prop)
+callback (Gsasl *ctx, Gsasl_session *sctx, Gsasl_property prop)
 {
   int rc = GSASL_NO_CALLBACK;
 
+  (void) ctx;
+
   switch (prop)
     {
     case GSASL_AUTHZID:
