@@ -1,5 +1,5 @@
 /* name.c --- Test the gsasl_mechanism_name function.
- * Copyright (C) 2008-2022 Simon Josefsson
+ * Copyright (C) 2008-2024 Simon Josefsson
  *
  * This file is part of GNU SASL.
  *
@@ -18,9 +18,7 @@
  *
  */
 
-#ifdef HAVE_CONFIG_H
-# include "config.h"
-#endif
+#include <config.h>
 
 #include <stdio.h>
 #include <stdarg.h>
