@@ -1,5 +1,5 @@
 /* saml20.c --- Test the SAML20 mechanism.
- * Copyright (C) 2010-2022 Simon Josefsson
+ * Copyright (C) 2010-2024 Simon Josefsson
  *
  * This file is part of GNU SASL.
  *
@@ -18,9 +18,7 @@
  *
  */
 
-#ifdef HAVE_CONFIG_H
-# include "config.h"
-#endif
+#include <config.h>
 
 #include <stdio.h>
 #include <stdarg.h>
@@ -57,10 +55,12 @@ const char *samlchallenge =
   "Vlc3RlZEF1dGhuQ29udGV4dD4gDQo8L3NhbWxwOkF1dGhuUmVxdWVzdD4=";
 
 static int
-client_callback (Gsasl * ctx, Gsasl_session * sctx, Gsasl_property prop)
+client_callback (Gsasl *ctx, Gsasl_session *sctx, Gsasl_property prop)
 {
   int rc = GSASL_NO_CALLBACK;
 
+  (void) ctx;
+
   /* The first round, the mechanism will need an authorization name
      and a SAML IDP.  The next round it will request that the client
      redirects the user (in the browser) using the data stored in the
@@ -91,10 +91,12 @@ client_callback (Gsasl * ctx, Gsasl_session * sctx, Gsasl_property prop)
 }
 
 static int
-server_callback (Gsasl * ctx, Gsasl_session * sctx, Gsasl_property prop)
+server_callback (Gsasl *ctx, Gsasl_session *sctx, Gsasl_property prop)
 {
   int rc = GSASL_NO_CALLBACK;
 
+  (void) ctx;
+
   /* The first round the mechanism will want the SAML challenge to
      send to the client.  The next round it wants an authorization
      decision. */
