@@ -1,5 +1,5 @@
 /* scram-nopasswd.c --- Test the SCRAM-SHA256 mechanism.
- * Copyright (C) 2009-2022 Simon Josefsson
+ * Copyright (C) 2009-2024 Simon Josefsson
  *
  * This file is part of GNU SASL.
  *
@@ -21,9 +21,7 @@
 /* This self-test is about making sure SCRAM works without a supplied
    password both in client and server mode. */
 
-#ifdef HAVE_CONFIG_H
-# include "config.h"
-#endif
+#include <config.h>
 
 #include <stdio.h>
 #include <stdarg.h>
@@ -48,10 +46,12 @@
 #define STOREDKEY "9e1uUmKhrFexDKE2zfHs3aCuRANzfnf5EQG6MFXvmKM="
 
 static int
-callback (Gsasl * ctx, Gsasl_session * sctx, Gsasl_property prop)
+callback (Gsasl *ctx, Gsasl_session *sctx, Gsasl_property prop)
 {
   int rc = GSASL_NO_CALLBACK;
 
+  (void) ctx;
+
   /* Get user info from user. */
 
   switch (prop)
