@@ -1,5 +1,5 @@
 /* scram-sha256.c --- Test the SCRAM-SHA256 mechanism.
- * Copyright (C) 2009-2022 Simon Josefsson
+ * Copyright (C) 2009-2024 Simon Josefsson
  *
  * This file is part of GNU SASL.
  *
@@ -18,9 +18,7 @@
  *
  */
 
-#ifdef HAVE_CONFIG_H
-# include "config.h"
-#endif
+#include <config.h>
 
 #include <stdio.h>
 #include <stdarg.h>
@@ -34,10 +32,12 @@
 #define PASSWORD "pencil"
 
 static int
-callback (Gsasl * ctx, Gsasl_session * sctx, Gsasl_property prop)
+callback (Gsasl *ctx, Gsasl_session *sctx, Gsasl_property prop)
 {
   int rc = GSASL_NO_CALLBACK;
 
+  (void) ctx;
+
   /* Get user info from user. */
 
   switch (prop)
