@@ -1,5 +1,5 @@
 /* scramplus.c --- Test the SCRAM-SHA-1-PLUS mechanism.
- * Copyright (C) 2009-2022 Simon Josefsson
+ * Copyright (C) 2009-2024 Simon Josefsson
  *
  * This file is part of GNU SASL.
  *
@@ -18,9 +18,7 @@
  *
  */
 
-#ifdef HAVE_CONFIG_H
-# include "config.h"
-#endif
+#include <config.h>
 
 #include <stdio.h>
 #include <stdarg.h>
@@ -47,10 +45,12 @@ static const char *AUTHZID[N_AUTHZID] = {
 int i;
 
 static int
-callback (Gsasl * ctx, Gsasl_session * sctx, Gsasl_property prop)
+callback (Gsasl *ctx, Gsasl_session *sctx, Gsasl_property prop)
 {
   int rc = GSASL_NO_CALLBACK;
 
+  (void) ctx;
+
   /* Get user info from user. */
 
   switch (prop)
@@ -179,8 +179,8 @@ doit (void)
 	    fail ("dummy initial server step produced output?!\n");
 
 	  if (debug)
-	    printf ("S: %.*s [%c]\n", (int) s1len,
-		    s1, res == GSASL_OK ? 'O' : 'N');
+	    printf ("S: %.*s [%s]\n", (int) s1len,
+		    s1, gsasl_strerror_name (res));
 	}
       else
 	{
@@ -199,8 +199,7 @@ doit (void)
 	}
 
       if (debug)
-	printf ("C: %.*s [%c]\n", (int) s1len,
-		s1, res == GSASL_OK ? 'O' : 'N');
+	printf ("C: %.*s [%s]\n", (int) s1len, s1, gsasl_strerror_name (res));
 
       /* Server first... */
 
@@ -214,8 +213,7 @@ doit (void)
 	}
 
       if (debug)
-	printf ("S: %.*s [%c]\n", (int) s2len,
-		s2, res == GSASL_OK ? 'O' : 'N');
+	printf ("S: %.*s [%s]\n", (int) s2len, s2, gsasl_strerror_name (res));
 
       /* Client final... */
 
@@ -244,23 +242,19 @@ doit (void)
 	s1[30] = 'B';
 
       if (debug)
-	printf ("C: %.*s [%c]\n", (int) s1len,
-		s1, res == GSASL_OK ? 'O' : 'N');
+	printf ("C: %.*s [%s]\n", (int) s1len, s1, gsasl_strerror_name (res));
 
       /* Server final... */
 
       res = gsasl_step (server, s1, s1len, &s2, &s2len);
       gsasl_free (s1);
-      if (i >= 17 && i <= 19)
+      if ((i == 17 && res == GSASL_BASE64_ERROR) ||
+	  (i == 18 && res == GSASL_AUTHENTICATION_ERROR) ||
+	  (i == 19 && res == GSASL_AUTHENTICATION_ERROR))
 	{
-	  if (res == GSASL_AUTHENTICATION_ERROR)
-	    {
-	      if (debug)
-		success ("Authentication failed expectedly\n");
-	      goto done;
-	    }
-	  else
-	    res = GSASL_AUTHENTICATION_ERROR;
+	  if (debug)
+	    success ("Authentication failed expectedly\n");
+	  goto done;
 	}
       if (res != GSASL_OK)
 	{
@@ -270,8 +264,7 @@ doit (void)
 	}
 
       if (debug)
-	printf ("S: %.*s [%c]\n", (int) s2len,
-		s2, res == GSASL_OK ? 'O' : 'N');
+	printf ("S: %.*s [%s]\n", (int) s2len, s2, gsasl_strerror_name (res));
 
       /* Let client parse server final... */
 
